@@ -1,6 +1,6 @@
 use strict;
 use warnings;
-use LWP::UserAgent;
+use LWP::Simple;
 
 #======================================================================
 # data: sample databases
@@ -14,7 +14,7 @@ my %databases = (
   },
 
   chinook => {
-    source => "http://download-codeplex.sec.s-msft.com//Download/Release?ProjectName=chinookdatabase&DownloadId=557773&FileTime=129989782797830000&Build=20919",
+    source => "http://download-codeplex.sec.s-msft.com/Download/Release?ProjectName=chinookdatabase&DownloadId=557773&FileTime=129989782797830000&Build=20907",
     dest   => $chinook_zip,
     hook   => sub {
       use Archive::Zip;
@@ -22,17 +22,10 @@ my %databases = (
       my $zip = Archive::Zip->new($chinook_zip);
       $zip->extractMember($member, "Chinook/$member");
       undef $zip;
-      # unlink $chinook_zip;
+      unlink $chinook_zip;
     },
   },
 
-  foo => {
-    source => "https://github.com/IntelliTree/RA-ChinookDemo/blob/master/chinook.db?raw=true",
-    dest => "foo.db",
-  },
-
-
-
  );
 
 
@@ -43,22 +36,14 @@ my %databases = (
 # choose databases to download
 my @to_download = @ARGV ? @ARGV : keys %databases;
 
-
-my $ua = LWP::UserAgent->new;
-
 # download each database
 foreach my $db_name (@to_download) {
   my $db = $databases{$db_name}
     or die "unknown database : $db_name";
-  print STDERR "downloading $db_name to $db->{dest} ...";
-  my $resp = $ua->mirror($db->{source}, $db->{dest});
-  if ($resp->is_success) {
-    print STDERR " running hook .. " and $db->{hook}->() if $db->{hook};
-    print STDERR "done\n";
-  }
-  else {
-    print STDERR $resp->status_line, "\n";
-  }
+  print STDERR "downloading $db_name ...";
+  mirror($db->{source}, $db->{dest});
+  $db->{hook}->() if $db->{hook};
+  print STDERR "done\n";
 }
 
 
